/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.core.log.logger;

import org.springblade.core.log.event.UsualLogPublisher;
import org.springblade.core.log.properties.PlatomixLogProperties;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;

import lombok.extern.slf4j.Slf4j;

/**
 * 日志工具类
 *
 * @author Chill
 */
@Slf4j
public class PlatomixLogger implements InitializingBean {

	@Value("${spring.application.name}")
	private String serviceId;
	
	@Autowired
	private PlatomixLogProperties logProperties;

	public void info(String id, String data) {
		if(logProperties.getUsualLogEnabled()) {
			UsualLogPublisher.publishEvent("info", id, data);
		}
	}

	public void debug(String id, String data) {
		if(logProperties.getUsualLogEnabled()) {
			UsualLogPublisher.publishEvent("debug", id, data);
		}
	}

	public void warn(String id, String data) {
		if(logProperties.getUsualLogEnabled()) {
			UsualLogPublisher.publishEvent("warn", id, data);
		}
	}

	public void error(String id, String data) {
		if(logProperties.getUsualLogEnabled()) {
			UsualLogPublisher.publishEvent("error", id, data);
		}
	}

	@Override
	public void afterPropertiesSet() throws Exception {
		if(logProperties.getUsualLogEnabled()) {
			log.info(serviceId + ": PlatomixLogger init success!");
		}
	}

}
