-- 用户画像模块 - 王坤
DROP TABLE IF EXISTS `profile_analysis_book`;
CREATE TABLE `profile_analysis_book` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `event_type` tinyint(4) NOT NULL COMMENT '事件类型(1-事件分析/2-留存分析/3-漏斗分析/4-分布分析)',
  `aly_name` varchar(100) NOT NULL COMMENT '分析名称',
  `aly_desc` varchar(1000) DEFAULT NULL COMMENT '分析说明',
  `content` longtext NOT NULL COMMENT 'json字符串',
  `share_status` tinyint(4) NOT NULL COMMENT '共享状态(0-独享 1-共享)',
  `default_status` tinyint(4) NOT NULL COMMENT '是否默认(0-否 1-是)',
  `create_user_id` bigint(20) NOT NULL,
  `create_by` varchar(100) NOT NULL COMMENT '创建人',
  `create_time` datetime NOT NULL COMMENT '创建时间',
  `update_by` varchar(100) DEFAULT NULL COMMENT '修改人',
  `update_time` datetime DEFAULT NULL COMMENT '修改时间',
  `tenant_id` varchar(12) DEFAULT NULL COMMENT '租户id',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='用户画像-行为分析-标签';

DROP TABLE IF EXISTS `profile_event`;
CREATE TABLE `profile_event` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键ID',
  `name` varchar(50) DEFAULT NULL COMMENT '事件名',
  `code` varchar(50) DEFAULT NULL COMMENT '事件code',
  `platform` varchar(50) DEFAULT NULL COMMENT '可埋点平台',
  `desc_message` varchar(50) DEFAULT NULL COMMENT '事件描述',
  `create_time` datetime DEFAULT NULL COMMENT '创建时间',
  `tenant_id` varchar(12) DEFAULT NULL COMMENT '租户id',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=233 DEFAULT CHARSET=utf8mb4 COMMENT='事件表';

INSERT INTO `profile_event` VALUES (232, '大屏预览', 'visualPreview', 'web/h5', '', '2023-11-15 12:50:08', '111111');

DROP TABLE IF EXISTS `profile_event_prop_map`;
CREATE TABLE `profile_event_prop_map` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键ID',
  `event_id` bigint(20) DEFAULT NULL COMMENT '事件ID',
  `prop_id` bigint(20) DEFAULT NULL COMMENT '属性ID',
  `prop_position` varchar(255) DEFAULT NULL COMMENT '事件属性位置',
  `create_time` datetime DEFAULT NULL COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=1558 DEFAULT CHARSET=utf8mb4 COMMENT='事件属性关联表';

INSERT INTO `profile_event_prop_map` VALUES (1551, 232, 152, 'attr1', '2023-11-24 15:09:32');
INSERT INTO `profile_event_prop_map` VALUES (1552, 232, 153, 'attr2', '2023-11-24 15:09:43');
INSERT INTO `profile_event_prop_map` VALUES (1553, 232, 154, 'attr3', '2023-11-24 15:09:51');
INSERT INTO `profile_event_prop_map` VALUES (1554, 232, 155, 'attr4', '2023-11-24 15:09:57');
INSERT INTO `profile_event_prop_map` VALUES (1555, 232, 156, 'attr5', '2023-11-24 15:10:04');
INSERT INTO `profile_event_prop_map` VALUES (1556, 232, 157, 'attr6', '2023-11-24 15:10:11');
INSERT INTO `profile_event_prop_map` VALUES (1557, 232, 143, 'attr7', '2023-11-24 15:10:24');

DROP TABLE IF EXISTS `profile_project`;
CREATE TABLE `profile_project` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键ID',
  `name` varchar(50) DEFAULT NULL COMMENT '项目名',
  `proj_code` varchar(500) DEFAULT NULL COMMENT '项目编码',
  `ptype_code` varchar(500) DEFAULT NULL COMMENT '项目类型编码',
  `platform` varchar(50) DEFAULT NULL COMMENT '平台',
  `desc_message` varchar(50) DEFAULT NULL COMMENT '项目描述',
  `create_time` datetime DEFAULT NULL COMMENT '创建时间',
  `tenant_id` varchar(12) DEFAULT NULL COMMENT '租户id',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=16 DEFAULT CHARSET=utf8mb4 COMMENT='项目表';

INSERT INTO `profile_project` VALUES (15, '几何BI', NULL, 'BI', 'web/h5', '', '2023-11-20 15:41:45', '111111');

DROP TABLE IF EXISTS `profile_project_event_map`;
CREATE TABLE `profile_project_event_map` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键ID',
  `project_id` bigint(20) DEFAULT NULL COMMENT '项目id',
  `event_id` bigint(20) DEFAULT NULL COMMENT '事件id',
  `level` int(11) DEFAULT NULL COMMENT '无等级 0  其他等级 1-5级',
  `sort` bigint(20) DEFAULT NULL COMMENT '排序',
  `prop_id_json` json DEFAULT NULL COMMENT '属性ID_JSON',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=232 DEFAULT CHARSET=utf8mb4 COMMENT='项目事件关联表';

INSERT INTO `profile_project_event_map` VALUES (231, 15, 232, 0, 0, '[152, 155, 143, 153, 156, 157, 154]');

DROP TABLE IF EXISTS `profile_prop`;
CREATE TABLE `profile_prop` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键ID',
  `name` varchar(50) DEFAULT NULL COMMENT '属性名',
  `code` varchar(50) DEFAULT NULL COMMENT '属性code',
  `type` int(11) DEFAULT NULL COMMENT '属性类别  事件属性1 用户属性0',
  `datatype` int(11) DEFAULT NULL COMMENT '数据类型 0 数字\n1 字符串\n2 布尔\n3 时间\n',
  `is_preset` int(11) DEFAULT NULL COMMENT '是否预置  0 否 1 是',
  `is_common` int(11) DEFAULT NULL COMMENT '是否公共属性 0 否 1 是',
  `desc_message` varchar(50) DEFAULT NULL COMMENT '属性描述',
  `options` text COMMENT '属性可选值json',
  `distributions` text COMMENT '属性预置区间json',
  `create_time` datetime DEFAULT NULL COMMENT '创建时间',
  `dic_table` varchar(50) DEFAULT NULL COMMENT '关联的字典表',
  `join_field` varchar(50) DEFAULT NULL COMMENT 'join的字段名称',
  `target_field` varchar(50) DEFAULT NULL COMMENT '要查询的字段名称',
  `order_field` varchar(255) DEFAULT NULL COMMENT '字典表的排序字段',
  `hidden_status` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否隐藏(1-是/0-否)',
  `tenant_id` varchar(12) DEFAULT NULL COMMENT '租户id',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=159 DEFAULT CHARSET=utf8mb4 COMMENT='属性表';

INSERT INTO `profile_prop` VALUES (152, '大屏类型', 'visualType', NULL, 1, 0, 0, '', '[]', '[]', '2023-11-15 12:47:02', '', '', '', NULL, 0, '111111');
INSERT INTO `profile_prop` VALUES (153, '大屏标题', 'visualTitle', NULL, 1, 0, 0, '', '[]', '[]', '2023-11-15 12:47:24', '', '', '', NULL, 0, '111111');
INSERT INTO `profile_prop` VALUES (154, '用户id', 'userId', NULL, 1, 0, 0, '', '[]', '[]', '2023-11-15 12:47:51', '', '', '', NULL, 0, '111111');
INSERT INTO `profile_prop` VALUES (155, '用户名', 'userName', NULL, 1, 0, 0, '', '[]', '[]', '2023-11-15 12:48:09', '', '', '', NULL, 0, '111111');
INSERT INTO `profile_prop` VALUES (156, '大屏分类', 'visualCategory', NULL, 1, 0, 0, '', '[]', '[]', '2023-11-15 12:48:25', '', '', '', NULL, 0, '111111');
INSERT INTO `profile_prop` VALUES (157, '租户id', 'tenandId', NULL, 1, 0, 0, '', '[]', '[]', '2023-11-15 12:49:01', '', '', '', NULL, 0, '111111');
INSERT INTO `profile_prop` VALUES (158, '来源', 'referer', NULL, 1, 0, 1, '', '[]', '[]', '2023-11-19 22:07:53', '', '', '', NULL, 0, '111111');